Learn R Programming

savonliquide (version 0.2.0)

check_contrast_raw: Color Contrast Accessibility Report in a Raw Format

Description

returns a report from the Contrast Checker API about color contrast for accessibility in a list format so that the information provided can be extracted and piped into other functions.

Usage

check_contrast_raw(fg_col, bg_col)

Arguments

fg_col

the Foreground Color

bg_col

the Background Color

Value

Color Contrast Report in a raw format

Examples

Run this code
# NOT RUN {
check_contrast_raw(fg_col = "#21EA06", bg_col = "#483D3D")


# }

Run the code above in your browser using DataLab