check_contrast_raw: Color Contrast Accessibility Report in a Raw Format
Description
returns a report from the Contrast Checker API about color contrast for accessibility in a list format
so that the information provided can be extracted and piped into other functions.